Cheetah.Tests.Unicode module — Cheetah3 - The Python-Powered Template Engine

# Cheetah.Tests.Unicode module

class `Cheetah.Tests.Unicode.` `CommandLineTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `createAndCompile`(source)

class `Cheetah.Tests.Unicode.` `EncodeUnicodeCompatTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Taken initially from Red Hat’s bugzilla #529332 https://bugzilla.redhat.com/show_bug.cgi?id=529332

  `runTest`()

class `Cheetah.Tests.Unicode.` `InlineSpanishTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `setUp`()
  `test_success`()

    Test a template with a proper #encoding tag

class `Cheetah.Tests.Unicode.` `JBQ_UTF8_Test1`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `runTest`()

class `Cheetah.Tests.Unicode.` `JBQ_UTF8_Test2`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `runTest`()

class `Cheetah.Tests.Unicode.` `JBQ_UTF8_Test3`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `runTest`()

class `Cheetah.Tests.Unicode.` `JBQ_UTF8_Test4`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `runTest`()

class `Cheetah.Tests.Unicode.` `JBQ_UTF8_Test5`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `runTest`()

class `Cheetah.Tests.Unicode.` `JBQ_UTF8_Test6`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `runTest`()

class `Cheetah.Tests.Unicode.` `JBQ_UTF8_Test7`(methodName='runTest')

  Bases: `Cheetah.Tests.Unicode.CommandLineTest`

  `runTest`()

class `Cheetah.Tests.Unicode.` `JBQ_UTF8_Test8`(methodName='runTest')

  Bases: `Cheetah.Tests.Unicode.CommandLineTest`

  `testDynamicCompile`()
  `testStaticCompile`()

class `Cheetah.Tests.Unicode.` `Unicode_in_SearchList_Test`(methodName='runTest')

  Bases: `Cheetah.Tests.Unicode.CommandLineTest`

  `test_BasicASCII`()
  `test_Thai`()
  `test_Thai_utf8`()

`Cheetah.Tests.Unicode.` `loadModule`(moduleName, path=None)